#! /usr/bin/env python
# -*- coding: utf-8 -*-

import AiDragonfly.aiqi_main as main

import asyncio

import time

from AiDragonfly.aiqi_bluetooth_save_json import Read_Local_Onebot_Device
from AiDragonfly.common.onebot_common_function import Aiqi_Print_HEX

mesh_super_conf_name_list = ["OneBot_XL_M", "OneBot_St_M", "OneBot_BL_M"]
mesh_super_conf_dev_list = []

__log_title = 'mesh_model '

'''
speed -100 至 100
'''


def __speed_to_xl_speed(speed):
    re_spd = 0
    spd = speed
    if spd > 100:
        spd = 100
    elif spd < -100:
        spd = -100

    if spd >= 0:
        re_spd = spd
    else:
        re_spd = 100 - spd
    if re_spd == 100:
        re_spd = 99

    return re_spd


'''
speed -100 至 100
'''


def __speed_to_bl_speed(speed):
    re_spd = 0
    spd = speed
    if spd > 100:
        spd = 100
    elif spd < -100:
        spd = -100
    re_spd = spd

    return re_spd


'''
speed -150 至 150
'''


def __speed_to_st_speed(speed):
    zero_angle = 173
    re_spd = 0
    spd = speed
    if spd > 150:
        spd = 150
    elif spd < -150:
        spd = -150
    re_spd = zero_angle + spd
    return re_spd


'''
速度buff ,如 speed_buff=[100,-100]
+100，对应xl 电机、平衡电机，速度正传100，
+100 对应舵机，左转100度
max value  100 电机
max value  150 舵机
min value -100 电机
min value -150 舵机
'''


def speed_ctrl(speed_buff):
    if len(speed_buff) == 0:
        print('please check speed_buff')
        return
    dev_len = len(mesh_super_conf_dev_list)
    dev_list = mesh_super_conf_dev_list

    tx_buf = bytearray(2+dev_len * 2)
    for i in tx_buf:
        i = 0
    tx_buf[0] = dev_len * 2
    tx_buf[1] = 122
    index = 0
    x = 0
    for spd in speed_buff:
        v1 = 0
        if dev_list[x].name == "OneBot_XL_M":
            v1 = __speed_to_xl_speed(spd)
        elif dev_list[x].name == "OneBot_BL_M":
            v1 = __speed_to_bl_speed(spd)
        elif dev_list[x].name == "OneBot_St_M":
            v1 = __speed_to_st_speed(spd)
        else:
            print('speed analy err')
            break
        tx_buf[2 + index] = v1 >> 8
        tx_buf[2 + index + 1] = v1 & 0xff
        index += 2
        x += 1
        if x > dev_len-1:
            break

    main.Aiqi_Bluetooth_Send(tx_buf)
    time.sleep(0.05)


'''
Currently only supports configuration "OneBot_XL_M","OneBot_St_M","OneBot_BL_M"
When configuring, it will automatically search and configure from the list by default, and the unsupported devices will automatically skip
Default first directly connected to the sweep

'''


def mesh_configure():
    global mesh_super_conf_dev_list
    local_dev = Read_Local_Onebot_Device()
    conf_item = []
    for localitem in local_dev:
        if localitem.name in mesh_super_conf_name_list:
            conf_item.append(localitem)
    mesh_super_conf_dev_list = conf_item[:]

    del conf_item[0]  #
    dev_len = len(conf_item)

    if dev_len == 0 or dev_len > 6:
        # print('dev num is ' + str(dev_len) + ',不需要super配置')
        return
    tx_buf = bytearray(5 + dev_len * 2)

    tx_buf[0] = 3 + dev_len * 2

    tx_buf[1] = 121
    # Aiqi_Print_HEX(tx_buf)
    dev_mes = [0, 0, 0, 0, 0, 0]  # 配置设备类型属性
    dev_mes_index = 0
    for item in conf_item:
        if item.name == 'OneBot_XL_M' or item.name == 'OneBot_BL_M':
            dev_mes[dev_mes_index] = 1
        elif item.name == 'OneBot_St_M':
            dev_mes[dev_mes_index] = 2
        tx_buf[5 + dev_mes_index] = item.mesh_addr >> 8
        tx_buf[5 + dev_mes_index + 1] = item.mesh_addr & 0xff
        dev_mes_index += 1

    tx_buf[2] = dev_mes[0] << 4 + dev_mes[1]
    tx_buf[3] = dev_mes[2] << 4 + dev_mes[3]
    tx_buf[4] = dev_mes[4] << 4 + dev_mes[5]
    try:
        main.Aiqi_Bluetooth_Send(tx_buf)
    except:
        print(__log_title+'bluetooth send err')
    print(__log_title+'configure ok')







#! /usr/bin/env python
# -*- coding: utf-8 -*-

SOUND_GENERAL_DOORBELL = 29
SOUND_GENERAL_ALAM = 30

SOUND_ROBOT_SPEED = 18
SOUND_ROBOT_TRANSFORM = 19
SOUND_ROBOT_SING = 20
SOUND_ROBOT_GUN = 21
SOUND_ROBOT_LASER = 22
SOUND_ROBOT_BROKEN = 23
SOUND_ROBOT_BOMB = 24

SOUND_DINOSAUR_ANGER = 25
SOUND_DINOSAUR_ATTACK = 26
SOUND_DINOSAUR_FIGHT = 27
SOUND_DINOSAUR_INJURED = 28


INSTRUMENTS_PIANO = 0
INSTRUMENTS_MUSIC_BOX = 10
INSTRUMENTS_BASS = 32
INSTRUMENTS_GUITAR = 24
INSTRUMENTS_SAXOPHONE = 64
INSTRUMENTS_FLUTE = 72
INSTRUMENTS_XYLOPHONE = 13
INSTRUMENTS_VIOLIN = 40
INSTRUMENTS_HARP = 46
INSTRUMENTS_PERCUSSION = 0

MIDI_DO_LOW_LOW = 36
MIDI_RE_LOW_LOW = 38
MIDI_MI_LOW_LOW = 40
MIDI_FA_LOW_LOW = 41
MIDI_SO_LOW_LOW = 43
MIDI_LA_LOW_LOW = 45
MIDI_SI_LOW_LOW = 47

MIDI_DO_LOW = 48
MIDI_RE_LOW = 50
MIDI_MI_LOW = 52
MIDI_FA_LOW = 53
MIDI_SO_LOW = 55
MIDI_LA_LOW = 57
MIDI_SI_LOW = 59

MIDI_DO = 60
MIDI_RE = 62
MIDI_MI = 64
MIDI_FA = 65
MIDI_SO = 67
MIDI_LA = 69
MIDI_SI = 71

MIDI_DO_HIGH = 72
MIDI_RE_HIGH = 74
MIDI_MI_HIGH = 76
MIDI_FA_HIGH = 77
MIDI_SO_HIGH = 79
MIDI_LA_HIGH = 81
MIDI_SI_HIGH = 83

MIDI_DO_HIGH_HIGH = 84
MIDI_RE_HIGH_HIGH = 86
MIDI_MI_HIGH_HIGH = 88
MIDI_FA_HIGH_HIGH = 89
MIDI_SO_HIGH_HIGH = 91
MIDI_LA_HIGH_HIGH = 93
MIDI_SI_HIGH_HIGH = 95

PERCUSSION_ACOUSTIC_BASS_DRUM = 35
PERCUSSION_BASS_DRUM_1 = 36
PERCUSSION_SIDE_STICK = 37
PERCUSSION_ACOUSTIC_SNARE = 38
PERCUSSION_HAND_CLAP = 39
PERCUSSION_ELECTRIC_SNARE = 40
PERCUSSION_LOW_FLOOR_TOM = 41
PERCUSSION_CLOSED_HI_HAT = 44
PERCUSSION_LOW_TOM = 45
PERCUSSION_OPEN_HI_HAT = 46
PERCUSSION_LOW_MID_TOM = 47
PERCUSSION_HI_MID_TOM = 48
PERCUSSION_CRASH_CYMBAL_1 = 49
PERCUSSION_HIGH_TOM = 50
PERCUSSION_RIDE_CYMBAL_1 = 51
PERCUSSION_CHINESE_CYMBAL = 52
PERCUSSION_RIDE_BELL = 53
PERCUSSION_TAMBOURINE = 54
PERCUSSION_SPLASH_CYMBAL = 55
PERCUSSION_COWBELL = 56
PERCUSSION_CRASH_CYMBAL_2 = 57
PERCUSSION_VIBRASLAP = 58
PERCUSSION_RIDE_CYMBAL_2 = 59
PERCUSSION_HI_BONGO = 60
PERCUSSION_LOW_BONGO = 61
PERCUSSION_MUTE_HI_CONGA = 62
PERCUSSION_OPEN_HI_CONGA = 63
PERCUSSION_LOW_CONGA = 64
PERCUSSION_HIGH_TIMBALE = 65
PERCUSSION_LOW_TIMBALE = 66
PERCUSSION_HIGH_AGOGO = 67
PERCUSSION_LOW_AGOGO = 68
PERCUSSION_CABASA = 69
PERCUSSION_MARACAS = 70
PERCUSSION_SHORT_WHISTLE = 71
PERCUSSION_LONG_WHISTLE = 72
PERCUSSION_SHORT_GUIRO = 73
PERCUSSION_LONG_GUIRO = 74
PERCUSSION_CLAVES = 75
PERCUSSION_HI_WOOD_BLOCK = 76
PERCUSSION_LOW_WOOD_BLOCK = 77
PERCUSSION_MUTE_GUICA = 78
PERCUSSION_OPEN_CUICA = 79
PERCUSSION_MUTE_TRIANGLE = 80
PERCUSSION_OPEN_TRIANGLE = 81



RECORD_START = 0x01
RECORD_END = 0x02
RECORD_PLAY = 0x03





MOTOR_PORTA = 0
MOTOR_PORTB = 1
MOTOR_PORTC = 2
MOTOR_PORTD = 3



SENSOR_DIGITAL_SERVO = 0x8B
SENSOR_OPTICAL = 0x52
SENSOR_BUZZER = 0x73
SENSOR_RGBLIGHT = 0x75
SENSOR_PHOTOSENSITIVE = 0x5B
SENSOR_LASER = 0x51
# SENSOR_FLAME = 0x55
SENSOR_GEOMAGNETIC = 0x56
SENSOR_ATTITUDE = 0x57

DIGITALSERVO_GETANGLE = 0
DIGITALSERVO_SETANGLE = 1
DIGITALSERVO_SETPOWER = 2

OPTICAL_COLOR = 0
OPTICAL_GRAY_SCALE = 1
OPTICAL_RGB = 2
OPTICAL_AMBIENT_LIGHT_INTENSITY = 3
OPTICAL_KEY_STATUS = 4
OPTICAL_LIGHT_UP = 5
# OPTICAL_SIGNAL_STRENGTH = 6

LASER_DISTANCE_MM = 0
LASER_DISTANCE_CM = 1
LASER_KEY_STATUS = 2
# LASER_SIGNAL_STRENGTH = 3

# FLAME_DIRECTION = 0
# FLAME_INTENSITY = 1
# FLAME_KEY_STATUS = 2
# FLAME_FOOTBALL_DIRECTION = 3

GEOMAGNETIC_FIELD_ANGLE = 0
GEOMAGNETIC_KEY_STATUS = 1

ATTITUDE_DICE = 0
ATTITUDE_KEY_STATUS = 1
ATTITUDE_ACCELERATION_X = 2
ATTITUDE_ACCELERATION_Y = 3
ATTITUDE_ACCELERATION_Z = 4
ATTITUDE_ANGULAR_VELOCITY_X = 5
ATTITUDE_ANGULAR_VELOCITY_Y = 6
ATTITUDE_ANGULAR_VELOCITY_Z = 7
# ATTITUDE_SIGNAL_STRENGTH = 8
# ATTITUDE_INCLINATION_ANGLE_X = 10
# ATTITUDE_STEPS = 9
# ATTITUDE_INCLINATION_ANGLE_Y = 11
# ATTITUDE_INCLINATION_ANGLE_Z = 12

BUZZER_VOLUME = 2
BUZZER_MUSIC = 3

BUZZER_TONE_HIGH = 3
BUZZER_TONE_MIDDLE = 2
BUZZER_TONE_LOW = 1

BUZZER_NOTE_DO = 1
BUZZER_NOTE_RE = 2
BUZZER_NOTE_MI = 3
BUZZER_NOTE_FA = 4
BUZZER_NOTE_SO = 5
BUZZER_NOTE_LA = 6
BUZZER_NOTE_SI = 7




RGBLIGHT_CONTROL = 2

PHOTOSENSITIVE_AMBIENT_LIGHT_INTENSITY = 2

MESH_MODE_MOTOR = 0
MESH_MODE_BALANCE = 1
MESH_MODE_PASSIVE = 2
MESH_MODE_ACTIVE = 3


















#! /usr/bin/env python
# -*- coding: utf-8 -*-
import atexit
import threading

import AiDragonfly
from bleak.backends.device import BLEDevice
from bleak.backends.scanner import AdvertisementData

from AiDragonfly.aiqi_model.bluetooth import aiqi_bluetooth
from AiDragonfly.comm_protocol.aiqi_blue_report import bluereport
from AiDragonfly.comm_protocol.aiqi_mesh_report import mesh_report, _mesh_login_class
from AiDragonfly.common.onebot_common_function import Aiqi_Print_HEX
from AiDragonfly.aiqi_model.ble_cc import constantModule, motorModule, musicModule, sensorModule
import asyncio
import time
import sys

# import aiqi_model

# The global variable
import AiDragonfly.aiqi_bluetooth_device_type as aiqi_blue_type
from AiDragonfly.Get_Mesh_Devices_Message import Get_Onebot_Device_Message_Init
import AiDragonfly.aiqi_bluetooth_save_json as aiqi_file

_volume = 0
_engine = 0
_voltage = 0
_regeditNum = 0
_regedit = [[0 for i in range(100)] for j in range(25)]
__dev_type = 0

blue_scan_parm = None
onebot_client = None

mesh_control_flag = 0
mesh_mode_flag = 0

mesh_config_ack = False


__onebot_login = _mesh_login_class()
__aiqi_adapter = aiqi_bluetooth.Aiqi_Bluetooth_Class()


def _protocol_analysis(num, data):  # 数据接收分析函数，根据报文协议 解析收到的数据
    global _regeditNum, _regedit, _volume, _engine, _voltage
    global i, __onebot_login
    global mesh_config_ack
    global mesh_control_flag, mesh_mode_flag
    length = num
    _receive_message = data
    # Aiqi_Print_HEX(data)
    if length > 3:  # 接收到的数据个数 小于三个 则抛弃
        if _receive_message[0] == 0x55:  # 红蓝主控的报文分析 0x55是红蓝主控协议的报头
            buf = _receive_message
            if buf[0] == 0x55 and buf[-1] == 0xAA:  # 协议报头 报尾
                if buf[1] == 0x01 and buf[2] == 0x04 and buf[3] == 0x01 and buf[4] == 0x00:  # 根据具体协议解析即可
                    _volume = buf[5]
                    _engine = buf[6]
                    # print('音量',buf)
                elif buf[1] == 0x02 and buf[2] == 0x06 and buf[3] == 0x00 and buf[4] == 0xC8:
                    volume = buf[8] * 256 + buf[9]
                    # print('Synchronous voltage')
                    # print('主控电压',buf)
                    pass
                elif buf[1] == 0x01 and buf[2] == 0x02 and buf[3] == 0x00 and buf[4] == 0x00:
                    # print('The heartbeat packets')
                    pass
                elif buf[1] == 0x01 and buf[2] == 0x03 and buf[3] == 0x00 and buf[4] == 0x01:
                    # print('The registry starts uploading')
                    pass
                elif buf[1] == 0x01 and buf[2] == 0x03 and buf[3] == 0x01 and buf[4] == 0x01:
                    # print('Registry upload complete')
                    pass
                elif buf[1] == 0x01 and buf[2] == 0x07 and buf[3] == 0x00:
                    # print('SN',buf)
                    pass
                elif buf[1] == 0x01 and buf[2] == 0x06 and buf[3] == 0x00:
                    musicModule._version = (
                                                   buf[4] << 24) + (buf[5] << 16) + (buf[6] << 8) + buf[7]
                    # print('固件版本号',buf)
                elif buf[1] == 0x01 and buf[2] == 0x06 and buf[3] == 0x01:
                    # print('语音版本号',buf)
                    pass
                elif buf[1] == 0x05 and buf[2] == 0x00 and buf[3] == 0x00:  # 注册信息处理
                    if _regeditNum == 0:  # 注册个数为零 存储第一条注册信息
                        # print('有新传感器,类型：', buf[5],'。  注册号：',buf[4],'已注册个数：',_regeditNum+1)
                        # print('数据：',buf)
                        _regedit[_regeditNum][0:20] = buf[0:20]
                        _regeditNum = _regeditNum + 1
                    else:
                        while True:
                            # 接收到注册报文后，先判断注册表中是否已存在此注册信息
                            for i in list(range(_regeditNum)):
                                tmp1 = buf[6:11]
                                tmp2 = bytearray(_regedit[i][6:11])
                                if tmp1 == tmp2:
                                    break
                                else:
                                    i = i + 1
                            if i == _regeditNum:  # 注册表中没有此条注册信息，填入注册表
                                # print('有新传感器,类型：', buf[5],'。  注册号：',buf[4],'已注册个数：',_regeditNum+1)
                                # print('数据：',buf)
                                _regedit[_regeditNum][0:20] = buf[0:20]
                                _regeditNum = _regeditNum + 1
                                break
                            else:
                                break
                # 以上主要为主控连接成功后的 初始交互信息和注册表
                # 下面主要是接收到传感器数据的处理
                elif buf[1] == 0x02 and buf[2] == 0x02 and buf[3] == 0x05:
                    motorModule.motor._rotation_completed_flag = 1
                    motorModule.motor._rotation_completed_port = buf[4]
                elif buf[1] == 0x02 and buf[2] == 0x06 and buf[3] == 0x00 and buf[4] == 0x0B:
                    if buf[11] == 4 or buf[11] == 5 or buf[11] == 6 or buf[11] == 7:
                        motorModule.motor._port_speed = buf[5] * 256 + buf[6]
                    elif buf[11] == 0 or buf[11] == 1 or buf[11] == 2 or buf[11] == 3:
                        motorModule.motor._port_angle = buf[5] * 256 + buf[6]

                elif buf[1] == 0x02 and buf[2] == 0x06 and buf[3] == 0x00:
                    if buf[10] == 0x00:  # 传感器状态在线
                        if buf[4] == sensorModule._sensor.regedit_num:  # 首先判断传感器注册号是否匹配
                            for i in list(range(_regeditNum)):
                                # 注册号匹配
                                if sensorModule._sensor.regedit_num == _regedit[i][4]:
                                    if _regedit[i][5] == constantModule.SENSOR_DIGITAL_SERVO:  # 舵机
                                        if buf[11] == constantModule.DIGITALSERVO_GETANGLE:
                                            motorModule.digitalServo._angle = buf[5] * \
                                                                              256 + buf[6]

                                    # 设备类型匹配,处理数据.这个是多功能颜色传感器
                                    elif _regedit[i][5] == constantModule.SENSOR_OPTICAL:
                                        if buf[11] == constantModule.OPTICAL_COLOR:  # 颜色
                                            sensorModule.sensor_optical._color = buf[6]
                                        elif buf[11] == constantModule.OPTICAL_GRAY_SCALE:  # 灰度
                                            sensorModule.sensor_optical._grayScale = buf[6]
                                        elif buf[11] == constantModule.OPTICAL_RGB:  # RGB
                                            sensorModule.sensor_optical._R = buf[5]
                                            sensorModule.sensor_optical._G = buf[6]
                                            sensorModule.sensor_optical._B = buf[7]
                                        # 环境光
                                        elif buf[11] == constantModule.OPTICAL_AMBIENT_LIGHT_INTENSITY:
                                            sensorModule.sensor_optical._ambientLightIntensity = buf[
                                                                                                     5] * 256 + buf[6]
                                        elif buf[11] == constantModule.OPTICAL_KEY_STATUS:
                                            sensorModule.sensor_optical._keyStatus = buf[6]
                                        # elif buf[11] == constantModule.OPTICAL_SIGNAL_STRENGTH:
                                        #     sensorModule.sensor_optical._signalStrength = buf[6]

                                    # 光敏传感器
                                    elif _regedit[i][5] == constantModule.SENSOR_PHOTOSENSITIVE:
                                        if buf[11] == constantModule.PHOTOSENSITIVE_AMBIENT_LIGHT_INTENSITY:
                                            sensorModule.sensor_photosensitive._ambientLightIntensity = buf[5] * 256 + \
                                                                                                        buf[6]

                                    elif _regedit[i][5] == constantModule.SENSOR_LASER:  # 激光传感器
                                        if buf[11] == constantModule.LASER_DISTANCE_MM:
                                            sensorModule.sensor_laser._distance_mm = buf[5] * \
                                                                                     256 + buf[6]
                                        elif buf[11] == constantModule.LASER_DISTANCE_CM:
                                            sensorModule.sensor_laser._distance_cm = buf[6]
                                        elif buf[11] == constantModule.LASER_KEY_STATUS:
                                            sensorModule.sensor_laser._keyStatus = buf[6]
                                        # elif buf[11] == constantModule.LASER_SIGNAL_STRENGTH:
                                        #     sensorModule.sensor_laser._signal_strength = buf[6]

                                    # elif _regedit[i][5] == constantModule.SENSOR_FLAME:
                                    #     if buf[11] == constantModule.FLAME_DIRECTION:
                                    #         sensorModule.sensor_infraredRadar._flameDirection = buf[6]
                                    #     elif buf[11] == constantModule.FLAME_INTENSITY:
                                    #         sensorModule.sensor_infraredRadar._flameIntensity = buf[6]
                                    #     elif buf[11] == constantModule.FLAME_KEY_STATUS:
                                    #         sensorModule.sensor_infraredRadar._keyStatus = buf[6]
                                    #     elif buf[11] == constantModule.FLAME_FOOTBALL_DIRECTION:
                                    #         sensorModule.sensor_infraredRadar._footballDirection = buf[6]

                                    elif _regedit[i][5] == constantModule.SENSOR_GEOMAGNETIC:  # 地磁传感器
                                        if buf[11] == constantModule.GEOMAGNETIC_FIELD_ANGLE:
                                            sensorModule.sensor_geomagnetic._magneticFieldAngle = buf[
                                                                                                      5] * 256 + buf[6]
                                        elif buf[11] == constantModule.GEOMAGNETIC_KEY_STATUS:
                                            sensorModule.sensor_geomagnetic._keyStatus = buf[6]

                                    elif _regedit[i][5] == constantModule.SENSOR_ATTITUDE:  # 六轴传感器
                                        if buf[11] == constantModule.ATTITUDE_DICE:
                                            sensorModule.sensor_attitude._dice = buf[6]
                                        # elif buf[11] == constantModule.ATTITUDE_STEPS:
                                        #     sensorModule.sensor_attitude._steps = buf[5]*256 + buf[6]
                                        # elif buf[11] == constantModule.ATTITUDE_SIGNAL_STRENGTH:
                                        #     sensorModule.sensor_attitude._signalStrength = buf[6]
                                        elif buf[11] == constantModule.ATTITUDE_KEY_STATUS:
                                            sensorModule.sensor_attitude._keyStatus = buf[6]
                                        elif buf[11] == constantModule.ATTITUDE_ACCELERATION_X:
                                            sensorModule.sensor_attitude._acceleration_X = buf[
                                                                                               5] * 256 + buf[6]
                                        elif buf[11] == constantModule.ATTITUDE_ACCELERATION_Y:
                                            sensorModule.sensor_attitude._acceleration_Y = buf[
                                                                                               5] * 256 + buf[6]
                                        elif buf[11] == constantModule.ATTITUDE_ACCELERATION_Z:
                                            sensorModule.sensor_attitude._acceleration_Z = buf[
                                                                                               5] * 256 + buf[6]
                                        elif buf[11] == constantModule.ATTITUDE_ANGULAR_VELOCITY_X:
                                            sensorModule.sensor_attitude._angularVelocity_X = buf[
                                                                                                  5] * 256 + buf[6]
                                        elif buf[11] == constantModule.ATTITUDE_ANGULAR_VELOCITY_Y:
                                            sensorModule.sensor_attitude._angularVelocity_Y = buf[
                                                                                                  5] * 256 + buf[6]
                                        elif buf[11] == constantModule.ATTITUDE_ANGULAR_VELOCITY_Z:
                                            sensorModule.sensor_attitude._angularVelocity_Z = buf[
                                                                                                  5] * 256 + buf[6]
                                        # elif buf[11] == constantModule.ATTITUDE_INCLINATION_ANGLE_X:
                                        #     sensorModule.sensor_attitude._inclinationAngle_X = buf[6]
                                        # elif buf[11] == constantModule.ATTITUDE_INCLINATION_ANGLE_Y:
                                        #     sensorModule.sensor_attitude._inclinationAngle_Y = buf[6]
                                        # elif buf[11] == constantModule.ATTITUDE_INCLINATION_ANGLE_Z:
                                        #     sensorModule.sensor_attitude._inclinationAngle_Z = buf[6]

                                    else:
                                        print('Sensor not found')
                    else:
                        print('sensor offline')
        elif _receive_message[0] == 0x01:  # mesh设备的处理报文
            buf = _receive_message
            if buf[1] == 0x79:  # 配置回应
                if buf[2] == 0:
                    mesh_config_ack = True
                elif buf[2] == 1:
                    mesh_config_ack = False
                else:
                    mesh_config_ack = False
            elif buf[1] == 0x53:  # 接收到随机值
                mesh_random = buf[2]
                __onebot_login.dev_random = buf[2]

                mesh_sn_flag = 0
            elif buf[1] == 0x47:  # 成功登录
                if buf[2] == 1:
                    __onebot_login.dev_login_stats = True
                else:
                    __onebot_login.dev_login_stats = False
            elif buf[1] == 0x81:  # 平衡机器人模式
                if buf[2] == 0:
                    mesh_mode_flag = 0
                elif buf[2] == 1:
                    mesh_mode_flag = 1
                elif buf[3] == 2:
                    mesh_mode_flag = 2
                elif buf[4] == 3:
                    mesh_mode_flag = 3

        elif _receive_message[0] == 0x04:  # mesh设备的处理报文  接收到版本号
            buf = _receive_message
            if buf[1] == 0x4C:
                v1 = buf[2] << 24
                v2 = buf[3] << 16
                v3 = buf[4] << 8
                v4 = buf[5]
                mesh_version = v1 + v2 + v3 + v4
                # print('version ' + str(mesh_version))
                __onebot_login.dev_version = mesh_version

        elif _receive_message[0] == 0x07:  # mesh设备的处理报文 接收到SN
            buf = _receive_message
            if buf[1] == 0x4E:
                __onebot_login.dev_sn = buf[2:9]


__dev_mac_addr = ''

__onebot_local_save_list = []

__get_message_done_stats = False


def __get_mssage_callback(dev_list):
    global __get_message_done_stats, __onebot_local_save_list

    __onebot_local_save_list = []
    __onebot_local_save_list = dev_list[:]
    __get_message_done_stats = True


__bluetooth_scan_list = []
__wait_char_stats = False
__print_char = ""
__print_char_num = 0
__print_char_num_max = 0
def __print_wait_char(time=0.1,maxnum=10):
    global __print_char,__print_char_num,__wait_char_stats
    __print_char_num_max = maxnum
    if __wait_char_stats:
        __print_char +='█'
        print("\r"+__print_char+"  "+str(__print_char_num)+"/"+str(maxnum), end='')
        threading.Timer(time, __print_wait_char,args=(time,maxnum)).start()
    __print_char_num += 1
    if __print_char_num > __print_char_num_max and __print_char_num_max != 0:
        __wait_char_stats = False


def __bluetooth_scan_callback(device: BLEDevice, advertisement_data: AdvertisementData):
    global __bluetooth_scan_list

    if device.name != '' and device.name is not None:
        if len(__bluetooth_scan_list) != 0:
            for item in __bluetooth_scan_list:
                if item.address == device.address:
                    return
        __bluetooth_scan_list.append(device)
        # print('bluetooth_scan_callback' + device.name + ' ' + device.address, "RSSI:", device.rssi)


def __user_console_select(devs):
    user_select_buff = devs[:]
    user_done = False
    devs_index = []
    user_new_buff = []
    for item in devs:
        devs_index.append(item.index)

    while not user_done:
        def checkvalid(check_buff):
            for i in check_buff:
                if i not in devs_index:
                    print(i)
                    print(devs_index)
                    return False
            return True
        aiqi_blue_type.Print_Scan_Onebot_Device(user_select_buff)
        print('Please enter a number to be connected Shown in red, multiple sequences separated by spaces,Or directly enter, all the default configuration')
        print('Input sequence, determine the control sequence, please choose according to your needs')
        user_input = input('Separated by a space：').split()
        if len(user_input) != 0:
            user_input = list(map(int,user_input))
            if checkvalid(user_input):
                user_new_buff = []
                for i in user_input:
                    for item in user_select_buff:
                        if item.index == i:
                            user_new_buff.append(item)
                user_done = True
            else:
                print("Input error, please try again")
        else:
            user_new_buff = user_select_buff[:]
            user_done = True
    return user_new_buff


__App_Reset = ''
async def onebot_getdevices_process():
    global __dev_type, __dev_mac_addr,__wait_char_stats

    global __bluetooth_scan_list, __get_message_done_stats

    local_save_list = []
    scan_stats = True
    if __App_Reset == 'new':
        aiqi_file.delete_local_save_device()
    else:
        local_save_list = aiqi_file.Read_Local_Onebot_Device()
    if len(local_save_list) == 0:
        print('No local storage device found')
    else:
        scan_stats = False
        __dev_mac_addr = local_save_list[0].devid
        __onebot_local_save_list = local_save_list[:]
        __dev_type = aiqi_blue_type.Read_Onebot_Device_type(__onebot_local_save_list)
    if scan_stats:
        print('Start scanning')
        __bluetooth_scan_list = []
        __aiqi_adapter.set_scan_callback_regiser(__bluetooth_scan_callback)
        scancnt = 40
        scan_timeout = 40
        await __aiqi_adapter.scan_ctrl(True)
        __wait_char_stats = True
        __print_wait_char(0.5,blue_scan_parm.scantimeout/0.5)

        await asyncio.sleep(blue_scan_parm.scantimeout+1)
        await __aiqi_adapter.scan_ctrl(False)
        __wait_char_stats = False
        print('\nscan stop')

        devices = __bluetooth_scan_list[:]
        devices = __aiqi_adapter.scan_devices_operation(
            devices, blue_scan_parm.scannamelist, blue_scan_parm.scanmaclist)
        __onebot_local_save_list = aiqi_blue_type.select_onebot_devices(
            devices, scan_name=blue_scan_parm.scannamelist)
        if len(devices) == 0:
            print(
                "\n" + '\033[1;31m Please Turn on the master motor power switch or Please insert the Bluetooth adapter \033[0m')
            sys.exit('aiqi quit')

        __dev_type = aiqi_blue_type.Read_Onebot_Device_type(__onebot_local_save_list)
        print('Getting information......')
        if __dev_type == aiqi_blue_type.aiqi_device_type_class.Aiqi_Onebot_Mesh_Dev:
            await Get_Onebot_Device_Message_Init(__onebot_local_save_list, __get_mssage_callback)
            while __get_message_done_stats is False:
                pass
                time.sleep(0.1)  # 等待获取完成
            __get_message_done_stats = False
            __onebot_local_save_list = __user_console_select(__onebot_local_save_list)[:]
        aiqi_file.Save_Local_Onebot_Device(__onebot_local_save_list)
        print("Successfully saved")
        # 获取设备信息
    print('The local device information is as follows:   ')
    aiqi_file.print_Local_Onebot_Device()
    time.sleep(1)  # 等待断开
    __dev_mac_addr = __onebot_local_save_list[0].devid


'''
onebot login
'''


async def __onebot_login_process():
    global __wait_char_stats
    try:
        print("Please wait for a connection, up to eight seconds......")
        __wait_char_stats = True
        __print_wait_char(0.5,30)
        await __aiqi_adapter.connect(__dev_mac_addr,timeout=8)

    except:
        __wait_char_stats = False
        print("\nDevice connection timeout")
        sys.exit("0")
    __wait_char_stats = False

    __aiqi_adapter.set_disconnect_callback_register(_disconnect_callback)
    __aiqi_adapter.set_receive_callback_register(_protocol_analysis)
    global onebot_client, ONEBOT_Connect_Stats

    if __dev_type == 1 or __dev_type == 4:  # 蓝主控
        print('shake .....')
        # 发送连接报文
        __aiqi_adapter.set_receive_callback_register(_protocol_analysis)
        await __aiqi_adapter.sendData(bluereport.create_connect)
        # await client.write_gatt_char(aiqi_uuid.Aiqi_Bluetooth_Rx_Char_Uuid, bluereport.create_connect)
        # await client.start_notify(aiqi_uuid.Aiqi_Bluetooth_Tx_Char_Uuid,
        #                           _protocol_analysis)  # 打开蓝牙设备的发送，接收数据都在_protocol_analysis函数中
        await asyncio.sleep(3)
        # await client.stop_notify(aiqi_uuid.Aiqi_Bluetooth_Tx_Char_Uuid)  # 停止蓝牙设备的发送

    elif __dev_type == 2 or __dev_type == 3:  # 红主控 or 越野车 同上
        print('shake .....')


    elif __dev_type == 5:  # mesh 设备 mesh设备连接后需要根据设备版本号判断是否加密
        print('Detection version.....', end='')
        await __aiqi_adapter.senddata(mesh_report.get_version)
        time.sleep(0.1)
        print('version ' + __onebot_login.Get_Version_Str())
        if __onebot_login.dev_version >= __onebot_login.need_login_version:
            await __aiqi_adapter.senddata(mesh_report.get_sn)
            time.sleep(0.1)
            if __onebot_login.dev_sn is not None:
                await __aiqi_adapter.senddata(mesh_report.get_random)
                await asyncio.sleep(0.05)
                time.sleep(0.1)
                mesh_report.mesh_sn = []
                mesh_report.mesh_sn = __onebot_login.dev_sn[:]
                mesh_report.mesh_random = __onebot_login.dev_random
                await __aiqi_adapter.senddata(mesh_report.login_in)
                await asyncio.sleep(0.05)
                time.sleep(0.1)
                if __onebot_login.dev_login_stats:
                    print('login ok')
                else:
                    print('login err')
                    sys.exit('login err')
            else:
                print('sn err')
                sys.exit('sn err')
        elif __onebot_login.dev_version == 0:
            print('versin err')
            sys.exit('err')
        else:
            print('free login')

    else:
        print('设备类型不存在:', __dev_type)
        sys.exit('未知的设备类型')


def Aiqi_Bluetooth_Send(data, log=False):
    if log:
        Aiqi_Print_HEX(data)
    if __onebot_login.dev_login_stats:
        data.append(__onebot_login.dev_random)
    if __aiqi_adapter.connect_stats is True:
        loop = asyncio.get_event_loop()
        loop.run_until_complete(sendDate(data))  # 配置设备 发送模式配置信息
    else:
        print('ble is disconnect')


def __Aiqi_Bluetooth_Retry_Connect():
    print('Aiqi_Bluetooth_Retry_Connect')


# 蓝牙发送数据
async def sendDate(data):
    databytes = bytearray(data)
    if __aiqi_adapter.connect_stats:
        await __aiqi_adapter.senddata(databytes)
    else:
        print('ble disconect')



User_Disconnect_Handle = None

def _disconnect_callback(res):
    global ONEBOT_Connect_Stats, onebot_client
    # print('disconnect')
    ONEBOT_Connect_Stats = False
    onebot_client = None
    __onebot_login.Clear()
    if User_Disconnect_Handle is not None:
        User_Disconnect_Handle(res)




def Aiqi_Bluetooth_Disconnect_CallBack_Register(callback):
    global User_Disconnect_Handle
    # print('connect callback reg')
    User_Disconnect_Handle = callback


ONEBOT_Connect_Stats = False

async def app_exit():
    await __aiqi_adapter.disconnect()
    time.sleep(0.1)

@atexit.register
def atexit_fun():
    print('sys exit')
    loop = asyncio.get_event_loop()
    loop.run_until_complete(app_exit())


'''
app_reset : if is 'new' ,will clear local save all devices

'''
def start(app_reset='',scantimeout=5,rssi=-100,namelist=[],maclist=[]):
    global blue_scan_parm,__App_Reset
    __App_Reset = app_reset.lower()
    print('start')
    parm = aiqi_blue_type.aiqi_bluetooth_scan_class()
    parm.scantimeout = scantimeout
    parm.scannamelist = namelist[:]
    parm.scanmaclist = maclist[:]

    blue_scan_parm = parm
    loop = asyncio.get_event_loop()
    loop.run_until_complete(onebot_getdevices_process())

    loop = asyncio.get_event_loop()
    loop.run_until_complete(__onebot_login_process())

    return onebot_client



# -*- coding: utf-8 -*-
# @Time    : 2021/8/9 9:04
# @Author  : liumingming
# @FileName: __init__.py.py
# @Company ：http://www.iqi-inc.com/

from AiDragonfly.aiqi_model.mesh import meshModule
from AiDragonfly.aiqi_model.ble_cc import constantModule
from AiDragonfly.aiqi_model.ble_cc import motorModule
from AiDragonfly.aiqi_model.ble_cc import musicModule
from AiDragonfly.aiqi_model.ble_cc import sensorModule
# from AiDragonfly.aiqi_model.bluetooth import aiqi_bluetooth


import asyncio
import platform
import sys
import time


from bleak import discover, BleakClient
from AiDragonfly.aiqi_model.bluetooth import aiqi_bluetooth


devs_buff = []
connect_index = None
connect_dev_done_callback = None

aiqi_adapter = aiqi_bluetooth.Aiqi_Bluetooth_Class()

def Blue_Rev_CallBack(datalen, data):
    # print(data)
    if(len(data)==20 and data[1]== 0x62):
        addr = data[18]<<8 |data[19]
        # print('mesh '+ devs_buff[connect_index].devid+ ' addr:'+str(addr))
        devs_buff[connect_index].mesh_addr=addr


async def _Darwin_GetMessage_Process():
    global connect_index
    for i in range(0,len(devs_buff)):
        try:
            await aiqi_adapter.connect(devs_buff[i].devid,timeout=8)
            await asyncio.sleep(1)
            time.sleep(0.3)
            connect_index = i
            aiqi_adapter.set_receive_callback_register(Blue_Rev_CallBack)
            dev_con = bytearray([0, 0x61])
            await aiqi_adapter.senddata(dev_con)
            time.sleep(0.1)
            await aiqi_adapter.disconnect()
            time.sleep(0.3)
        except:
            i -= 1
            print('connect err')
            print('连接失败，未获取到设备信息，即将退出')
            sys.exit('程序退出')
    if connect_dev_done_callback is not None:
        connect_dev_done_callback(devs_buff)

def _mesh_mac_to_netaddr(dev_mac_addr):  # mesh设备 mac地址转换网络地址
    global onebot_local_save_list
    netadd = None

    tmp0 = int(dev_mac_addr[0], 16)
    tmp1 = int(dev_mac_addr[1], 16)
    tmp3 = int(dev_mac_addr[3], 16)
    tmp4 = int(dev_mac_addr[4], 16)
    tmp6 = int(dev_mac_addr[6], 16)
    tmp7 = int(dev_mac_addr[7], 16)
    one = tmp0 * 16 + tmp1
    two = tmp3 * 16 + tmp4
    three = tmp6 * 16 + tmp7
    netadd = (three % 20) * 1000 + two * 10 + one

    return netadd


def _windowns_getmeshmessage_process():
    global devs_buff
    for i in range(0,len(devs_buff)):
        devs_buff[i].mesh_addr = _mesh_mac_to_netaddr(devs_buff[i].devid)
    if connect_dev_done_callback is not None:
        connect_dev_done_callback(devs_buff)




async def Get_Onebot_Device_Message_Init(dev_buf,done_callback):
    global devs_buff,connect_dev_done_callback
    connect_dev_done_callback = done_callback
    devs_buff = []
    devs_buff = dev_buf[:]
    run_system = platform.system()
    # run_system = "Darwin"
    if run_system == "Darwin":
        await _Darwin_GetMessage_Process()
    elif run_system == "Windows":
        _windowns_getmeshmessage_process()
    else:
        sys.exit('系统不支持')




# -*- coding: utf-8 -*-
# @Time    : 2021/8/9 9:04
# @Author  : liumingming
# @FileName: __init__.py.py
# @Company ：http://www.iqi-inc.com/

import platform
import sys

from AiDragonfly.aiqi_main import start
from AiDragonfly.aiqi_main import Aiqi_Bluetooth_Disconnect_CallBack_Register

import AiDragonfly.aiqi_bluetooth_device_type as scan_blue
import AiDragonfly.aiqi_model as model


__run_system = platform.system()

if __run_system == "Darwin":
    pass
elif __run_system == "Windows":
    platform.release()
    if platform.release() == '10':
        pass
        win_ver = platform.version()
        win_verlist = win_ver.split('.')
        __ver_h = win_verlist[0]
        __ver_M = win_verlist[1]
        __ver_L = win_verlist[2]
        print(__run_system + " " + platform.release() + ' ' + platform.version())
    else:
        print(__run_system+" "+platform.release()+' '+platform.version())
        print('系统不支持')
        sys.exit('系统不支持')
    pass
else:
    print('系统不支持')
    sys.exit('系统不支持')




import codecs
import os
import sys
import io
from shutil import rmtree

try:
    from setuptools import find_packages, setup, Command
except:
    from distutils.core import setup


with open("README.rst", "r",encoding="utf-8") as fh:
    LONG_DESCRIPTION = fh.read()

NAME = "AiDragonfly"

DESCRIPTION = "AiDragonfly 是爱其科技推出的python编程包，和ONEBOT主控、智能积木主控深度融合，和手机端拖块编程 Dragonfly 一脉相承."

KEYWORDS = "AiDragonfly 是支持ONEBOT主控的python编程包"

AUTHOR = "Beijing IQI Technology Co., LTD"

AUTHOR_EMAIL = "liumingming@iqi-inc.com"

URL = "https://gitee.com/beijing-aiqi/ai-dragonfly.git"

VERSION = "2.3.2"

LICENSE = "MIT"

setup(
    name=NAME,
    version=VERSION,
    description=DESCRIPTION,
    long_description=LONG_DESCRIPTION,
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
    ],
    include_package_data=True,
    install_requires = [
    'bleak >=0.12.1',
    ],
    keywords=KEYWORDS,
    author=AUTHOR,
    author_email=AUTHOR_EMAIL,
    url=URL,
    license=LICENSE,
    packages=find_packages(),
    package_data = {
        # 任何包中含有.dll文件，都包含它
        '': ['*.dll','*.pyd'],
    },
)


import datetime


def onebot_xor_check(data):  # 异或校验函数 主要用于报文的校验
    value = 0x00
    for i in data:
        value = value ^ i
    return value

'''
十六进制字符串输出
'''
def Aiqi_Print_HEX(hexbuf,title=''):
    curr_time = datetime.datetime.now()
    time_str = datetime.datetime.strftime(curr_time, '%Y-%m-%d %H:%M:%S')
    print(title+time_str+" "+" ".join([hex(c).replace('0x', '').rjust(2,'0') for c in hexbuf]))



def _int2hex(data, bitnum):  # 数据类型转换函数

    if data < 0:
        if bitnum == 8:
            bdata = bin(data & 0xff)
            cdata = bdata[2:10]
        elif bitnum == 16:
            bdata = bin(data & 0xFFFF)
            cdata = bdata[2:18]
        ldata = []
        for i in cdata:
            ldata.append(i)
        sdata = ''
        for i in ldata:
            sdata = sdata + str(i)
        fdata = int(sdata, 2)
        return fdata
    else:
        fdata = data
        return fdata


def _hex2int(hexnum, bitnum):
    if (bitnum == 8) and (0xFF >= hexnum >= 0x80):
        return ~(0xFF ^ hexnum)
    elif (bitnum == 16) and (0xFFFF >= hexnum >= 0x8000):
        return ~(0xFFFF ^ hexnum)
    elif (bitnum == 32) and (0xFFFFFFFF >= hexnum >= 0x80000000):
        return ~(0xFFFFFFFF ^ hexnum)
    else:
        return hexnum


